#!/bin/bash

PROJECT_HOME="$(realpath -s --relative-to . "$(dirname "$0")/..")" || exit
. "$PROJECT_HOME/scripts/util.sh" || exit

APP="$1"
[ -n "$APP" ] || error "Usage: $0 <app name>"

get_carch
get_product

IMAGE="${APP}_${ARCH}_app_image"
IMAGE_NAME="localhost/${APP}_${ARCH}_app_image:latest"
IMAGE_SHORT_TAG="localhost/${APP}_app_image:latest"
IMAGE_SRC="$PROJECT_HOME/container"
IMAGE_TAR="$PROJECT_HOME/swu/$IMAGE.tar"

build_image() {
	local packages context="$IMAGE_SRC"
	if podman image exists "$IMAGE_NAME"; then
		if ! prompt_yesno n $"$IMAGE_NAME already exists, rebuild (not needed for app update)? [y/N]"; then
			return
		fi
		podman rmi "$IMAGE_NAME"
	fi

	packages=$(awk '!/^#/ { printf("%s ", $0) }' "$IMAGE_SRC/packages.txt") \
		|| error $"Could not read $IMAGE_SRC/packages.txt"

	# Ignore for releases: build forbids symlinks outside of build
	# directory, so use external context for extension development.
	if [ -L "$IMAGE_SRC/resources" ]; then
		context="$PROJECT_HOME/../container_common"
	fi

	podman build -t "$IMAGE_NAME" --squash \
			--build-arg ARCH="$CARCH" \
			--build-arg PRODUCT="${PRODUCT//"/"/_}" \
			--build-arg PACKAGES="$packages" \
			-f "$IMAGE_SRC/Dockerfile" \
			"$context" \
		|| error $"Could not build image"
}

save_image() {
	# We use the same tag on Armadillo regardless of arch,
	# just always retag
	podman tag "$IMAGE_NAME" "$IMAGE_SHORT_TAG"

	rm -f "$IMAGE_TAR"
	podman save -o "$IMAGE_TAR" "$IMAGE_SHORT_TAG" \
		|| error $"Could not save image"

	echo $"Stored container image to $IMAGE_TAR"
}

build_image
save_image
